@@ -1,4 +1,4 @@
-#' @title Core of the Pearson estimating function.
+#' @title Core of Pearson estimating functions
 #' @author Wagner Hugo Bonat
 #'
 #' @description Core of the Pearson estimating function.
@@ -6,11 +6,13 @@
 #' @param product A matrix.
 #' @param inv_C A matrix.
 #' @param res A vector of residuals.
+#' @param W Matrix of weights.
 #' @return A vector
 #' @keywords internal
 #' @details It is an internal function.
 
-mc_core_pearson <- function(product, inv_C, res) {
+mc_core_pearson <- function(product, inv_C, res, W) {
+    product <- product %*% W
     output <- t(res) %*% product %*%
         (inv_C %*% res) - sum(diag(product))
     return(as.numeric(output))
