@@ -46,7 +46,8 @@ mc_ma <- function(id, time, data, order = 1) {
     return(output)
   }
   data$id2 <- 1:dim(data)[1]
-  data <- data[order(data[id]),]
+  #data <- data[order(data[id]),]
+  data <- data[do.call(base::order, as.list(data[id])),]
   data$id3 <- 1:dim(data)[1]
   Z1.list <- list()
   data.id <- split(data, data[id], drop = TRUE)
