@@ -49,7 +49,8 @@ mc_rw <- function(id, time, data, order = 1, proper = FALSE) {
         return(output)
     }
     data$id2 <- 1:dim(data)[1]
-    data <- data[order(data[id]),]
+    #data <- data[order(data[id]),]
+    data <- data[do.call(base::order, as.list(data[id])),]
     data$id3 <- 1:dim(data)[1]
     if(proper == TRUE) {
         Z1.list <- list()
