@@ -17,6 +17,6 @@
 mc_sensitivity <- function(product, W) {
     #sourceCpp("src/mc_sensitivity_op.cpp")
     Sensitivity <- mc_sensitivity_op(products = product, W = W)
-    Sensitivity <- forceSymmetric(Sensitivity, uplo = FALSE)
+    Sensitivity <- forceSymmetric(Sensitivity, uplo = "L")
     return(Sensitivity)
 }
